==> sched-assist-war-1.0.0-sources.jar: org/jasig/schedassist/web/owner/schedule/ClearAvailableScheduleFormBackingObject.java <==
/**
 * Licensed to Jasig under one or more contributor license
 * agreements. See the NOTICE file distributed with this work
 * for additional information regarding copyright ownership.
 * Jasig licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a
 * copy of the License at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */


package org.jasig.schedassist.web.owner.schedule;


/**
 * Form backing object for {@link ClearWeekFormController} and {@link ClearEntireAvailableScheduleFormController}.
 * 
 * @author Nicholas Blair, nblair@doit.wisc.edu
 * @version $Id: ClearAvailableScheduleFormBackingObject.java 1713 2010-02-15 16:23:42Z npblair $
 */
public class ClearAvailableScheduleFormBackingObject {

	private boolean confirmedCancelAll = false;
	private boolean confirmedCancelWeek = false;
	private String weekOfPhrase;
	/**
	 * @return the confirmedCancelAll
	 */
	public boolean isConfirmedCancelAll() {
		return confirmedCancelAll;
	}
	/**
	 * @param confirmedCancelAll the confirmedCancelAll to set
	 */
	public void setConfirmedCancelAll(boolean confirmedCancelAll) {
		this.confirmedCancelAll = confirmedCancelAll;
	}
	/**
	 * @return the confirmedCancelWeek
	 */
	public boolean isConfirmedCancelWeek() {
		return confirmedCancelWeek;
	}
	/**
	 * @param confirmedCancelWeek the confirmedCancelWeek to set
	 */
	public void setConfirmedCancelWeek(boolean confirmedCancelWeek) {
		this.confirmedCancelWeek = confirmedCancelWeek;
	}
	/**
	 * @return the weekOfPhrase
	 */
	public String getWeekOfPhrase() {
		return weekOfPhrase;
	}
	/**
	 * @param weekOfPhrase the weekOfPhrase to set
	 */
	public void setWeekOfPhrase(String weekOfPhrase) {
		this.weekOfPhrase = weekOfPhrase;
	}

}

==> sched-assist-war-1.0.6-sources.jar: org/jasig/schedassist/web/owner/schedule/ClearAvailableScheduleFormBackingObject.java <==
/**
 * Licensed to Jasig under one or more contributor license
 * agreements. See the NOTICE file distributed with this work
 * for additional information regarding copyright ownership.
 * Jasig licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a
 * copy of the License at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */


package org.jasig.schedassist.web.owner.schedule;

import java.util.Date;


/**
 * Form backing object for {@link ClearWeekFormController} and {@link ClearEntireAvailableScheduleFormController}.
 * 
 * @author Nicholas Blair, nblair@doit.wisc.edu
 * @version $Id: ClearAvailableScheduleFormBackingObject.java 1713 2010-02-15 16:23:42Z npblair $
 */
public class ClearAvailableScheduleFormBackingObject {

	private boolean confirmedCancelAll = false;
	private boolean confirmedCancelWeek = false;
	private String weekOfPhrase;
	/**
	 * @return the confirmedCancelAll
	 */
	public boolean isConfirmedCancelAll() {
		return confirmedCancelAll;
	}
	/**
	 * @param confirmedCancelAll the confirmedCancelAll to set
	 */
	public void setConfirmedCancelAll(boolean confirmedCancelAll) {
		this.confirmedCancelAll = confirmedCancelAll;
	}
	/**
	 * @return the confirmedCancelWeek
	 */
	public boolean isConfirmedCancelWeek() {
		return confirmedCancelWeek;
	}
	/**
	 * @param confirmedCancelWeek the confirmedCancelWeek to set
	 */
	public void setConfirmedCancelWeek(boolean confirmedCancelWeek) {
		this.confirmedCancelWeek = confirmedCancelWeek;
	}
	/**
	 * @return the weekOfPhrase
	 */
	public String getWeekOfPhrase() {
		return weekOfPhrase;
	}
	/**
	 * @param weekOfPhrase the weekOfPhrase to set
	 */
	public void setWeekOfPhrase(String weekOfPhrase) {
		this.weekOfPhrase = weekOfPhrase;
	}
	/* (non-Javadoc)
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + (confirmedCancelAll ? 1231 : 1237);
		result = prime * result + (confirmedCancelWeek ? 1231 : 1237);
		result = prime * result
				+ ((weekOfPhrase == null) ? 0 : weekOfPhrase.hashCode());
		return result;
	}
	/* (non-Javadoc)
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		ClearAvailableScheduleFormBackingObject other = (ClearAvailableScheduleFormBackingObject) obj;
		if (confirmedCancelAll != other.confirmedCancelAll)
			return false;
		if (confirmedCancelWeek != other.confirmedCancelWeek)
			return false;
		if (weekOfPhrase == null) {
			if (other.weekOfPhrase != null)
				return false;
		} else if (!weekOfPhrase.equals(other.weekOfPhrase))
			return false;
		return true;
	}
	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "ClearAvailableScheduleFormBackingObject [confirmedCancelAll="
				+ confirmedCancelAll + ", confirmedCancelWeek="
				+ confirmedCancelWeek + ", weekOfPhrase=" + weekOfPhrase + "]";
	}

}
